#
# spec file for package fzf
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           fzf
Version:        0.17.4
Release:        2.2
Summary:        A command-line fuzzy finder
License:        MIT
Group:          Productivity/File utilities
URL:            https://github.com/junegunn/fzf
Source0:        https://github.com/junegunn/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.xz
# PATCH-FIX-SUSE  Build a position independent executable
Patch0:         build-mode-pie.patch
BuildRequires:  golang(API) >= 1.7

%description
fzf is an interactive Unix filter for command-line that can be used with any list; files,
command history, processes, hostnames, bookmarks, git commits, etc.

%package tmux
Summary:        Tmux integration for fzf
Supplements:    packageand(fzf:tmux)
BuildArch:      noarch

%description tmux
Tmux integration for fzf. Includes a wrapper script, fzf-tmux, that opens your list in a
separate tmux pane.

%package bash-completion
Summary:        Bash completion for fzf
Requires:       bash-completion
Supplements:    packageand(fzf:bash)
BuildArch:      noarch

%description bash-completion
Bash shell completions for fzf

%package zsh-completion
Summary:        ZSH completion for fzf
Supplements:    packageand(fzf:zsh)
BuildArch:      noarch

%description zsh-completion
zsh shell completions for fzf

%prep
%setup -q -a1
%patch0 -p1
# fix  E: env-script-interpreter
sed -i 's,#!%{_bindir}/env ,#!/bin/,' ./bin/fzf-tmux

%build
make %{?_smp_mflags}

%install
make bin/fzf
install -Dm755 bin/fzf %{buildroot}%{_bindir}/fzf
install -Dm755 bin/fzf-tmux %{buildroot}%{_bindir}/fzf-tmux
install -Dm644 man/man1/fzf.1 %{buildroot}%{_mandir}/man1/fzf.1
install -Dm644 man/man1/fzf-tmux.1 %{buildroot}%{_mandir}/man1/fzf-tmux.1

# shell completions
install -Dm0644 shell/completion.bash   %{buildroot}%{_sysconfdir}/bash_completion.d/fzf
install -Dm0644 shell/key-bindings.bash %{buildroot}%{_sysconfdir}/bash_completion.d/fzf-key-bindings
install -Dm0644 shell/completion.zsh %{buildroot}%{_datadir}/zsh/site-functions/_fzf
install -Dm0644 shell/key-bindings.zsh %{buildroot}%{_sysconfdir}/zsh_completion.d/fzf-key-bindings

%files
%doc README.md
%{_bindir}/fzf
%{_mandir}/man1/fzf.1%{?ext_man}
%license LICENSE

%files tmux
%{_bindir}/fzf-tmux
%{_mandir}/man1/fzf-tmux.1%{?ext_man}

%files bash-completion
%{_sysconfdir}/bash_completion.d/fzf
%{_sysconfdir}/bash_completion.d/fzf-key-bindings

%files zsh-completion
%{_datadir}/zsh
%dir %{_sysconfdir}/zsh_completion.d
%config %{_sysconfdir}/zsh_completion.d/fzf-key-bindings

%changelog
* Mon Jun 11 2018 avindra@opensuse.org
- update to 0.17.4
  * Added --layout option with a new layout called reverse-list.
  - -layout=reverse is a synonym for --reverse
  - -layout=default is a synonym for --no-reverse
  * Preview window will be updated even when there is no match for
    the query if any of the placeholder expressions (e.g. {q}, {+})
    evaluates to a non-empty string.
  * More keys for binding: shift-{up,down}, alt-{up,down,left,
    right}
  * fzf can now start when /dev/tty is not available by making
    an educated guess.
  * bash/zsh completion improvements
  * install and uninstall scripts support generating files under
    XDG_CONFIG_HOME on --xdg flag.
- remove sed patch for non-excecutable fix (merged upstream)
* Sun Apr  1 2018 avindra@opensuse.org
- initial package
